@@ -1,5 +1,6 @@
 import re
 import textwrap
+from typing import List
 
 
 def extract_indent(x: str) -> str:
@@ -9,8 +10,8 @@ def extract_indent(x: str) -> str:
     return m.group(1)
 
 
-def left_align(*texts, prefix=""):
-    blocks = []
+def left_align(*texts: str, prefix: str = ""):
+    blocks: List[str] = []
     for t in texts:
         blocks.append(textwrap.indent(textwrap.dedent(t), prefix=prefix))
     return "\n".join(blocks)
